==> bobmodules_0.15.3.zip: bobmodules_0.15.3/prototypes/item/electronics.lua <==
data:extend(
{
  {
    type = "tool",
    name = "module-case",
    icon = "__bobmodules__/graphics/icons/module-case.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-0[module-case]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "module-contact",
    icon = "__bobmodules__/graphics/icons/module-contact.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-1[module-contact]",
    stack_size = 200
  },

  {
    type = "tool",
    name = "module-circuit-board",
    icon = "__bobmodules__/graphics/icons/module-circuit-board.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-b4[module-circuit-board]",
    stack_size = 200,
    durability = 1,
  },
}
)




data:extend(
{
  {
    type = "item",
    name = "module-processor-board",
    icon = "__bobmodules__/graphics/icons/module-processor-board.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-b5[module-processor-board-1]",
    stack_size = 200
  },

  {
    type = "item",
    name = "module-processor-board-2",
    icon = "__bobmodules__/graphics/icons/module-processor-board-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-b6[module-processor-board-2]",
    stack_size = 200
  },

  {
    type = "item",
    name = "module-processor-board-3",
    icon = "__bobmodules__/graphics/icons/module-processor-board-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-b7[module-processor-board-3]",
    stack_size = 200
  },
}
)


data:extend(
{
  {
    type = "tool",
    name = "speed-processor",
    icon = "__bobmodules__/graphics/icons/speed-processor.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c4[speed-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "speed-processor-2",
    icon = "__bobmodules__/graphics/icons/speed-processor-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c4[speed-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "speed-processor-3",
    icon = "__bobmodules__/graphics/icons/speed-processor-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c4[speed-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "effectivity-processor",
    icon = "__bobmodules__/graphics/icons/effectivity-processor.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c5[effectivity-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "effectivity-processor-2",
    icon = "__bobmodules__/graphics/icons/effectivity-processor-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c5[effectivity-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "effectivity-processor-3",
    icon = "__bobmodules__/graphics/icons/effectivity-processor-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c5[effectivity-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "productivity-processor",
    icon = "__bobmodules__/graphics/icons/productivity-processor.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c6[productivity-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "productivity-processor-2",
    icon = "__bobmodules__/graphics/icons/productivity-processor-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c6[productivity-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "productivity-processor-3",
    icon = "__bobmodules__/graphics/icons/productivity-processor-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c6[productivity-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "pollution-clean-processor",
    icon = "__bobmodules__/graphics/icons/pollution-clean-processor.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c7[pollution-clean-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "pollution-clean-processor-2",
    icon = "__bobmodules__/graphics/icons/pollution-clean-processor-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c7[pollution-clean-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "pollution-clean-processor-3",
    icon = "__bobmodules__/graphics/icons/pollution-clean-processor-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c7[pollution-clean-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "pollution-create-processor",
    icon = "__bobmodules__/graphics/icons/pollution-create-processor.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c8[pollution-create-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "pollution-create-processor-2",
    icon = "__bobmodules__/graphics/icons/pollution-create-processor-2.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c8[pollution-create-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "pollution-create-processor-3",
    icon = "__bobmodules__/graphics/icons/pollution-create-processor-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "module-intermediates",
    order = "c-c8[pollution-create-processor-3]",
    stack_size = 100
  },
}
)

==> bobmodules_1.1.2.zip: bobmodules_1.1.2/prototypes/item/electronics.lua <==
data:extend(
{
  {
    type = "tool",
    name = "module-case",
    icon = "__bobmodules__/graphics/icons/module-case.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-0[module-case]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "module-contact",
    icon = "__bobmodules__/graphics/icons/module-contact.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-1[module-contact]",
    stack_size = 200
  },

  {
    type = "tool",
    name = "module-circuit-board",
    icon = "__bobmodules__/graphics/icons/module-circuit-board.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-b4[module-circuit-board]",
    stack_size = 200,
    durability = 1,
  },
}
)




data:extend(
{
  {
    type = "item",
    name = "module-processor-board",
    icon = "__bobmodules__/graphics/icons/module-processor-board.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-b5[module-processor-board-1]",
    stack_size = 200
  },

  {
    type = "item",
    name = "module-processor-board-2",
    icon = "__bobmodules__/graphics/icons/module-processor-board-2.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-b6[module-processor-board-2]",
    stack_size = 200
  },

  {
    type = "item",
    name = "module-processor-board-3",
    icon = "__bobmodules__/graphics/icons/module-processor-board-3.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-b7[module-processor-board-3]",
    stack_size = 200
  },
}
)


data:extend(
{
  {
    type = "tool",
    name = "speed-processor",
    icon = "__bobmodules__/graphics/icons/speed-processor.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c4[speed-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "speed-processor-2",
    icon = "__bobmodules__/graphics/icons/speed-processor-2.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c4[speed-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "speed-processor-3",
    icon = "__bobmodules__/graphics/icons/speed-processor-3.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c4[speed-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "effectivity-processor",
    icon = "__bobmodules__/graphics/icons/effectivity-processor.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c5[effectivity-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "effectivity-processor-2",
    icon = "__bobmodules__/graphics/icons/effectivity-processor-2.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c5[effectivity-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "effectivity-processor-3",
    icon = "__bobmodules__/graphics/icons/effectivity-processor-3.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c5[effectivity-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "productivity-processor",
    icon = "__bobmodules__/graphics/icons/productivity-processor.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c6[productivity-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "productivity-processor-2",
    icon = "__bobmodules__/graphics/icons/productivity-processor-2.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c6[productivity-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "productivity-processor-3",
    icon = "__bobmodules__/graphics/icons/productivity-processor-3.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c6[productivity-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "pollution-clean-processor",
    icon = "__bobmodules__/graphics/icons/pollution-clean-processor.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c7[pollution-clean-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "pollution-clean-processor-2",
    icon = "__bobmodules__/graphics/icons/pollution-clean-processor-2.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c7[pollution-clean-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "pollution-clean-processor-3",
    icon = "__bobmodules__/graphics/icons/pollution-clean-processor-3.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c7[pollution-clean-processor-3]",
    stack_size = 100
  },
}
)

data:extend(
{
  {
    type = "tool",
    name = "pollution-create-processor",
    icon = "__bobmodules__/graphics/icons/pollution-create-processor.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c8[pollution-create-processor-1]",
    stack_size = 100,
    durability = 1,
  },

  {
    type = "item",
    name = "pollution-create-processor-2",
    icon = "__bobmodules__/graphics/icons/pollution-create-processor-2.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c8[pollution-create-processor-2]",
    stack_size = 100
  },

  {
    type = "item",
    name = "pollution-create-processor-3",
    icon = "__bobmodules__/graphics/icons/pollution-create-processor-3.png",
    icon_size = 32,
    subgroup = "module-intermediates",
    order = "c-c8[pollution-create-processor-3]",
    stack_size = 100
  },
}
)
